@@ -26,12 +26,19 @@ prognameandversion = progname ++ " " ++ version :: String
 
 uiflags = [
   -- flagNone ["debug-ui"]  (\opts -> setboolopt "rules-file" opts) "run with no terminal output, showing console"
-   flagReq  ["theme"] (\s opts -> Right $ setopt "theme" s opts) "THEME" ("use this custom display theme ("++intercalate ", " themeNames++")")
+   flagNone ["watch"] (\opts -> setboolopt "watch" opts) "watch for data and date changes and reload automatically"
+  ,flagReq  ["theme"] (\s opts -> Right $ setopt "theme" s opts) "THEME" ("use this custom display theme ("++intercalate ", " themeNames++")")
   ,flagReq  ["register"] (\s opts -> Right $ setopt "register" s opts) "ACCTREGEX" "start in the (first) matched account's register"
+  ,flagNone ["change"] (\opts -> setboolopt "change" opts)
+    "show period balances (changes) at startup instead of historical balances"
+  -- ,flagNone ["cumulative"] (\opts -> setboolopt "cumulative" opts)
+  --   "show balance change accumulated across periods (in multicolumn reports)"
+  -- ,flagNone ["historical","H"] (\opts -> setboolopt "historical" opts)
+  --   "show historical ending balance in each period (includes postings before report start date)\n "
   ,flagNone ["flat"] (\opts -> setboolopt "flat" opts) "show full account names, unindented"
   -- ,flagReq ["drop"] (\s opts -> Right $ setopt "drop" s opts) "N" "with --flat, omit this many leading account name components"
   -- ,flagReq  ["format"] (\s opts -> Right $ setopt "format" s opts) "FORMATSTR" "use this custom line format"
-  ,flagNone ["no-elide"] (\opts -> setboolopt "no-elide" opts) "don't compress empty parent accounts on one line"
+  -- ,flagNone ["no-elide"] (\opts -> setboolopt "no-elide" opts) "don't compress empty parent accounts on one line"
   ,flagNone ["value","V"] (setboolopt "value") "show amounts as their current market value in their default valuation commodity (accounts screen)"
  ]
 
@@ -51,13 +58,15 @@ uimode =  (mode "hledger-ui" [("command","ui")]
 
 -- hledger-ui options, used in hledger-ui and above
 data UIOpts = UIOpts {
-     debug_ui_ :: Bool
-    ,cliopts_   :: CliOpts
+     watch_   :: Bool
+    ,change_  :: Bool
+    ,cliopts_ :: CliOpts
  } deriving (Show)
 
 defuiopts = UIOpts
     def
     def
+    def
 
 -- instance Default CliOpts where def = defcliopts
 
@@ -65,8 +74,9 @@ rawOptsToUIOpts :: RawOpts -> IO UIOpts
 rawOptsToUIOpts rawopts = checkUIOpts <$> do
   cliopts <- rawOptsToCliOpts rawopts
   return defuiopts {
-              debug_ui_ = boolopt "debug-ui" rawopts
-             ,cliopts_   = cliopts
+              watch_   = boolopt "watch" rawopts
+             ,change_  = boolopt "change" rawopts
+             ,cliopts_ = cliopts
              }
 
 checkUIOpts :: UIOpts -> UIOpts
